#
# spec file for package python-py-moneyed
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-py-moneyed
Version:        3.0
Release:        3.1
Summary:        Python currency and money classes
License:        BSD-3-Clause
URL:            https://github.com/limist/py-moneyed
Source:         https://github.com/py-moneyed/py-moneyed/archive/refs/tags/v%{version}.tar.gz#/py-moneyed-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Add XCG -- Caribbean guilder
#                        ZWG -- Zimbabwean ZiG
Patch0:         add-missing-currencies.patch
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Babel >= 2.8.0
Requires:       python-typing-extensions >= 3.7.4.3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module mypy >= 0.812}
BuildRequires:  %{python_module Babel >= 2.8.0}
BuildRequires:  %{python_module pytest >= 2.3.0}
BuildRequires:  %{python_module typing-extensions >= 3.7.4.3}
# /SECTION
%python_subpackages

%description
Provides Currency and Money classes for use in your Python code.

%prep
%autosetup -p1 -n py-moneyed-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/moneyed
%{python_sitelib}/py_moneyed-%{version}.dist-info

%changelog
* Fri Feb 14 2025 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch add-missing-xcg.patch, subsumed into:
- Add patch add-missing-currencies.patch:
  * Support the Zimbabwean ZiG (ZWG) as well.
* Wed Dec 11 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch add-missing-xcg.patch:
  * Support the upcoming Caribbean guilder (XCG)
- Switch to pyproject macros.
* Mon Nov 28 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.0:
  - Added SLE & VED currencies.
  - Removed support for Python 3.6.
  - Added support for Python 3.10 & 3.11.
- Remove upstreamed patch 178_missing_currencies.patch.
* Mon Jul 11 2022 Matej Cepl <mcepl@suse.com>
- Add 178_missing_currencies.patch to add two missing currencies
  (gh#py-moneyed/py-moneyed#178).
* Mon Jul 11 2022 Matej Cepl <mcepl@suse.com>
- Skip test_all_babel_currencies (gh#py-moneyed/py-moneyed#178).
* Tue Feb  1 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0:
  * Dropped support for Python 2.7 and 3.5 and PyPy 2.
  * Dropped the moneyed.localization module that was deprecated and
    announced for removal in 1.0.
  * Added type hints along with a mypy pre-commit hook.
  * Removed undocumented DEFAULT_CURRENCY and DEFAULT_CURRENCY_CODE
    constants, and change to make instantiating Money without providing a
    currency a type error. This used to result in an object with a made-up
    "XYZ" currency, which could lead to surprising behaviors and bugs.
  * Added zero property to Currency to conveniently access the zero value
    of a given currency.
  * Moved to use setuptool's declarative packaging config and PEP 517
    isolated builds.
  * Removed requirements files and instead specified test requirements
    using extras.
- Switch to using the GitHub release URL.
* Tue Mar 31 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.8.0
